Music House: negozio di strumenti musicali online dal 1946
Description: Strumenti musicali online e libri musicali: chitarre, bassi, pianoforti, tastiere, batterie e molto altro ancora!

Home page Orari Chi siamo Dove siamo
| Cerca: |
Ti trovi in: Home Page
Alcuni marchi Modalità di pagamento Contrassegno Bonifico per l'Italia Bonifico per l'Estero Postepay Informazioni |
Offerte valide solo a Dicembre 2015
Tastiera pesata in legno naturale Natural Wood X YAMAHA Clavinova CLP-545BK pianoforte tasti in legno nero € 1.999,00 | 12 dicembre presentazione ufficiale in negozio! L'inizio di una nuova era. Casio Bechstein CELVIANO Grand Hybrid gp300 pianoforte ibrido tasti in legno con martelletto € 2.770,00
PROMOZIONE: pianoforte + mobile IN LEGNO Casio Privia Px150 bk pianoforte 88 tasti con tastiera ivory realmente pesata € 480,00 | 12 dicembre presentazione ufficiale in negozio! Casio Grand Hybrid GP-500 Bechstein Celviano pianoforte ibrido con tastiera con martelletto gp500 nero lucido € 3.890,00
uno strumento idoneo per iniziare a studio il pianoforte con 88 tasti pesati Casio CDP120 pianoforte 88 tasti pesati € 350,00 | INDICATA PER BAMBINI DAI 6 A 10 ANNI COMET JUNIOR Batteria per bambin 5 pezzi completa di piatti e sgabello Contattaci
Violino elettrico silent 4/4 Carlo Giordano € 330,00 | Greg Bennet TR1 torino diavoletto black € 250,00
DB TECHNOLOGIES WM210L radio microfono lavalier DB TECHNOLOGIES WM210L radio microfono lavalier € 125,00 | amplificatori valvolari a tasso zero!!!! Line6 by Bogner Spider valve 112 - 40W amplificatore interamente valvolare € 790,00
trasporto gratuito Walden d350ce acustica elettrificata € 289,00 | Jazz?? Ecco la batteria che ti serve by TAMA !! TAMA IS58HS5 batteria Shell kit Jazz blu notte € 519,00
promozione spaciale Korg PA300 tastiera arranger € 640,00 | novità autunno 2015! Pianoforte 88 tasti pesati con touch screen Casio Privia PX-360 bk pianoforte 88 tasti touch screen € 899,00
Yamaha AC1R chitarra elettroacustica € 780,00 | MILLER A-818L SAX ALTO completo di fa# IN MIB MILLER A-818L SAX ALTO completo di fa# modello economico da studio € 450,00
Vintage VS6 chitarra elettrica tipo diavoletto sg Gloss Black € 350,00 | Mavis violoncello 3/4 completo di borsa imbottita e archetto modello da studio € 419,00
Eko NXT Gipsy Natural chitarra acustica spalla mancante € 182,00 | promo speciale UFIP CLASS 13'' charleston hi-hat con borsa Ufip e garanzia € 229,00
Sonor Champion Line CB78-RBHG bongos € 82,50 | PROMOZIONE SPECIALE SU TUTTE LE CRAVATTE DISPONIBILI Cravatte musicali con note e strumenti € 28,50
limited edition! Ibanez TCY20103 mtb twister Character limited edition € 299,00 | legni di alta qualita', suono corposo e profondo,una chitarra tutta da suonare............. Ibanez chitarra acustica jumbo SGT430E CS sfumato rosso LIMITED EDITION con accordatore € 440,00
PROMOZIONE MILLER FIATI PER LA SCUOLA Miller TR6330 tromba in sib con case rigido con anello e chiave alla 1° e 3° pompa completa di astuccio € 240,00 | ZILDJIAN A THIN CRASH 16'' BRILLANT ZILDJIAN A THIN CRASH 16'' BRILLANT piatto per batteria € 195,00
promo 50 anni insieme! ZILDJIAN DARK CRASH 14'' serie k € 219,00 | YAMAHA bocchino as 4c SAX ALTO as4C becco € 40,00
EKO BA 4C EQ Florence basso acustico elettrificato spalla mancante natural € 339,00 | Ibanez SR 800 4 corde attivo Ibanez SR 800 4 corde attivo € 479,00
promo speciale Metronomo Widescreen Pro Flip Top per batteria orchestra archi e fiati € 58,00 |
Ultimi arrivi
Vox Ac Clip tune accordatore € 25,00 | Diamonica Angel 27 tasti con borsa clavietta melodica € 24,00
QUIK LOK FAP05 filtro anti pop professionale e di materiale superiore per microfono € 49,00 | Eko DUO mini natural chitarra acustica travel 3/4 € 155,00
Eko Nxt parlor mini travel natural chitarra acustica 3/4 € 127,00 | Eko NXT Parlor Black acustica mini travel € 127,00
EKO VPB-100 LH Black Left Handed basso mancino € 189,00 | Angel ax25 n2 glockenspiel 25 piastre metallofono xilofono € 20,00
| Newsletter gratuita Prezzo da € a € Cerca nella categoria: Marca:
Condizioni di vendita | Post vendita | Diritto di recesso | Privacy | FAQ | Lavora con noi | Sei un rivenditore? | Link Log-in Music House Bari - P. IVA: 04718980727 Music House è in viale Einaudi 12/abc, 70125 BARI (Italy) Tel/Fax: 080/5019521 Tutti i nomi dei prodotti, i logotipi, i marchi ed i simboli sono di proprietà delle rispettive società. © Copyright 2005-2015 Aproweb. Tutti i diritti riservati. Pagina elaborata in 0,4219 secondi.